@@ -19,17 +19,15 @@
 # License, Version 2.0.
 #
 
-"""Generates tarballs for Git trees.
-
-"""
+"""Generates tarballs for Git trees."""
 
 import posixpath
 import stat
-import tarfile
 import struct
-from os import SEEK_END
-from io import BytesIO
+import tarfile
 from contextlib import closing
+from io import BytesIO
+from os import SEEK_END
 
 
 class ChunkedBytesIO:
@@ -43,7 +41,7 @@ class ChunkedBytesIO:
             list_of_bytestrings)
     """
 
-    def __init__(self, contents):
+    def __init__(self, contents) -> None:
         self.contents = contents
         self.pos = (0, 0)
 
