@@ -20,7 +20,7 @@
 
 """Reading and writing Git configuration files.
 
-TODO:
+Todo:
  * preserve formatting when updating configuration files
  * treat subsection names as case-insensitive for [branch.foo] style
    subsections
@@ -28,8 +28,11 @@ TODO:
 
 import os
 import sys
+from contextlib import suppress
 from typing import (
+    Any,
     BinaryIO,
+    Dict,
     Iterable,
     Iterator,
     KeysView,
@@ -41,8 +44,7 @@ from typing import (
     overload,
 )
 
-from dulwich.file import GitFile
-
+from .file import GitFile
 
 SENTINEL = object()
 
@@ -59,9 +61,9 @@ def lower_key(key):
 
 class CaseInsensitiveOrderedMultiDict(MutableMapping):
 
-    def __init__(self):
-        self._real = []
-        self._keyed = {}
+    def __init__(self) -> None:
+        self._real: List[Any] = []
+        self._keyed: Dict[Any, Any] = {}
 
     @classmethod
     def make(cls, dict_in=None):
@@ -82,7 +84,7 @@ class CaseInsensitiveOrderedMultiDict(MutableMapping):
 
         return out
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._keyed)
 
     def keys(self) -> KeysView[Tuple[bytes, ...]]:
@@ -97,11 +99,11 @@ class CaseInsensitiveOrderedMultiDict(MutableMapping):
     def values(self):
         return self._keyed.values()
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key, value) -> None:
         self._real.append((key, value))
         self._keyed[lower_key(key)] = value
 
-    def __delitem__(self, key):
+    def __delitem__(self, key) -> None:
         key = lower_key(key)
         del self._keyed[key]
         for i, (actual, unused_value) in reversed(list(enumerate(self._real))):
@@ -191,6 +193,7 @@ class Config:
           section: Tuple with section name and optional subsection name
           name: Name of the setting, including section and possible
             subsection.
+
         Returns:
           Contents of the setting
         """
@@ -265,7 +268,7 @@ class ConfigDict(Config, MutableMapping[Section, MutableMapping[Name, Value]]):
         self._values = CaseInsensitiveOrderedMultiDict.make(values)
 
     def __repr__(self) -> str:
-        return "{}({!r})".format(self.__class__.__name__, self._values)
+        return f"{self.__class__.__name__}({self._values!r})"
 
     def __eq__(self, other: object) -> bool:
         return isinstance(other, self.__class__) and other._values == self._values
@@ -630,9 +633,15 @@ def _find_git_in_win_path():
     for exe in ("git.exe", "git.cmd"):
         for path in os.environ.get("PATH", "").split(";"):
             if os.path.exists(os.path.join(path, exe)):
-                # exe path is .../Git/bin/git.exe or .../Git/cmd/git.exe
+                # in windows native shells (powershell/cmd) exe path is
+                # .../Git/bin/git.exe or .../Git/cmd/git.exe
+                #
+                # in git-bash exe path is .../Git/mingw64/bin/git.exe
                 git_dir, _bin_dir = os.path.split(path)
                 yield git_dir
+                parent_dir, basename = os.path.split(git_dir)
+                if basename == "mingw32" or basename == "mingw64":
+                    yield parent_dir
                 break
 
 
@@ -652,13 +661,11 @@ def _find_git_in_win_reg():
         )
 
     for key in (winreg.HKEY_CURRENT_USER, winreg.HKEY_LOCAL_MACHINE):  # type: ignore
-        try:
+        with suppress(OSError):
             with winreg.OpenKey(key, subkey) as k:  # type: ignore
                 val, typ = winreg.QueryValueEx(k, "InstallLocation")  # type: ignore
                 if typ == winreg.REG_SZ:  # type: ignore
                     yield val
-        except OSError:
-            pass
 
 
 # There is no set standard for system config dirs on windows. We try the
@@ -682,12 +689,12 @@ class StackedConfig(Config):
 
     def __init__(
         self, backends: List[ConfigFile], writable: Optional[ConfigFile] = None
-    ):
+    ) -> None:
         self.backends = backends
         self.writable = writable
 
     def __repr__(self) -> str:
-        return "<{} for {!r}>".format(self.__class__.__name__, self.backends)
+        return f"<{self.__class__.__name__} for {self.backends!r}>"
 
     @classmethod
     def default(cls) -> "StackedConfig":
@@ -756,7 +763,7 @@ class StackedConfig(Config):
 
 
 def read_submodules(path: str) -> Iterator[Tuple[bytes, bytes, bytes]]:
-    """read a .gitmodules file."""
+    """Read a .gitmodules file."""
     cfg = ConfigFile.from_path(path)
     return parse_submodules(cfg)
 
@@ -779,8 +786,7 @@ def parse_submodules(config: ConfigFile) -> Iterator[Tuple[bytes, bytes, bytes]]
 
 
 def iter_instead_of(config: Config, push: bool = False) -> Iterable[Tuple[str, str]]:
-    """Iterate over insteadOf / pushInsteadOf values.
-    """
+    """Iterate over insteadOf / pushInsteadOf values."""
     for section in config.sections():
         if section[0] != b'url':
             continue
@@ -800,8 +806,7 @@ def iter_instead_of(config: Config, push: bool = False) -> Iterable[Tuple[str, s
 
 
 def apply_instead_of(config: Config, orig_url: str, push: bool = False) -> str:
-    """Apply insteadOf / pushInsteadOf to a URL.
-    """
+    """Apply insteadOf / pushInsteadOf to a URL."""
     longest_needle = ""
     updated_url = orig_url
     for needle, replacement in iter_instead_of(config, push):
