@@ -34,8 +34,8 @@ import paramiko
 import paramiko.client
 
 
-class _ParamikoWrapper(object):
-    def __init__(self, client, channel):
+class _ParamikoWrapper:
+    def __init__(self, client, channel) -> None:
         self.client = client
         self.channel = channel
 
@@ -70,10 +70,10 @@ class _ParamikoWrapper(object):
         self.channel.close()
 
 
-class ParamikoSSHVendor(object):
+class ParamikoSSHVendor:
     # http://docs.paramiko.org/en/2.4/api/client.html
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         self.kwargs = kwargs
 
     def run_command(
