@@ -26,70 +26,42 @@
 # TODO(fbo): Second attempt to _send() must be notified via real log
 # TODO(fbo): More logs for operations
 
+import json
 import os
-import stat
-import zlib
-import tempfile
 import posixpath
-
+import stat
+import sys
+import tempfile
 import urllib.parse as urlparse
-
-from io import BytesIO
+import zlib
 from configparser import ConfigParser
+from io import BytesIO
+
 from geventhttpclient import HTTPClient
 
-from dulwich.greenthreads import (
-    GreenThreadsMissingObjectFinder,
-    GreenThreadsObjectStoreIterator,
-)
-
-from dulwich.lru_cache import LRUSizeCache
-from dulwich.objects import (
-    Blob,
-    Commit,
-    Tree,
-    Tag,
-    S_ISGITLINK,
-)
-from dulwich.object_store import (
-    PackBasedObjectStore,
-    PACKDIR,
-    INFODIR,
-)
-from dulwich.pack import (
-    PackData,
+from ..greenthreads import GreenThreadsMissingObjectFinder
+from ..lru_cache import LRUSizeCache
+from ..object_store import INFODIR, PACKDIR, PackBasedObjectStore
+from ..objects import S_ISGITLINK, Blob, Commit, Tag, Tree
+from ..pack import (
     Pack,
+    PackData,
     PackIndexer,
     PackStreamCopier,
-    write_pack_header,
+    _compute_object_size,
     compute_file_sha,
     iter_sha1,
-    write_pack_index_v2,
     load_pack_index_file,
     read_pack_header,
-    _compute_object_size,
     unpack_object,
+    write_pack_header,
+    write_pack_index_v2,
     write_pack_object,
 )
-from dulwich.protocol import TCP_GIT_PORT
-from dulwich.refs import (
-    InfoRefsContainer,
-    read_info_refs,
-    write_info_refs,
-)
-from dulwich.repo import (
-    BaseRepo,
-    OBJECTDIR,
-)
-from dulwich.server import (
-    Backend,
-    TCPGitServer,
-)
-
-import json
-
-import sys
-
+from ..protocol import TCP_GIT_PORT
+from ..refs import InfoRefsContainer, read_info_refs, write_info_refs
+from ..repo import OBJECTDIR, BaseRepo
+from ..server import Backend, TCPGitServer
 
 """
 # Configuration file sample
@@ -119,15 +91,6 @@ cache_length = 20
 """
 
 
-class PackInfoObjectStoreIterator(GreenThreadsObjectStoreIterator):
-    def __len__(self):
-        while self.finder.objects_to_send:
-            for _ in range(0, len(self.finder.objects_to_send)):
-                sha = self.finder.next()
-                self._shas.append(sha)
-        return len(self._shas)
-
-
 class PackInfoMissingObjectFinder(GreenThreadsMissingObjectFinder):
     def next(self):
         while True:
@@ -152,7 +115,7 @@ class PackInfoMissingObjectFinder(GreenThreadsMissingObjectFinder):
 
 
 def load_conf(path=None, file=None):
-    """Load configuration in global var CONF
+    """Load configuration in global var CONF.
 
     Args:
       path: The path to the configuration file
@@ -170,8 +133,9 @@ def load_conf(path=None, file=None):
     if not path:
         try:
             confpath = os.environ["DULWICH_SWIFT_CFG"]
-        except KeyError:
-            raise Exception("You need to specify a configuration file")
+        except KeyError as exc:
+            raise Exception(
+                "You need to specify a configuration file") from exc
     else:
         confpath = path
     if not os.path.isfile(confpath):
@@ -181,7 +145,7 @@ def load_conf(path=None, file=None):
 
 
 def swift_load_pack_index(scon, filename):
-    """Read a pack index file from Swift
+    """Read a pack index file from Swift.
 
     Args:
       scon: a `SwiftConnector` instance
@@ -233,11 +197,11 @@ class SwiftException(Exception):
     pass
 
 
-class SwiftConnector(object):
-    """A Connector to swift that manage authentication and errors catching"""
+class SwiftConnector:
+    """A Connector to swift that manage authentication and errors catching."""
 
-    def __init__(self, root, conf):
-        """Initialize a SwiftConnector
+    def __init__(self, root, conf) -> None:
+        """Initialize a SwiftConnector.
 
         Args:
           root: The swift container that will act as Git bare repository
@@ -294,8 +258,7 @@ class SwiftConnector(object):
         if ret.status_code < 200 or ret.status_code >= 300:
             raise SwiftException(
                 "AUTH v1.0 request failed on "
-                + "%s with error code %s (%s)"
-                % (
+                + "{} with error code {} ({})".format(
                     str(auth_httpclient.get_base_url()) + path,
                     ret.status_code,
                     str(ret.items()),
@@ -330,8 +293,7 @@ class SwiftConnector(object):
         if ret.status_code < 200 or ret.status_code >= 300:
             raise SwiftException(
                 "AUTH v2.0 request failed on "
-                + "%s with error code %s (%s)"
-                % (
+                + "{} with error code {} ({})".format(
                     str(auth_httpclient.get_base_url()) + path,
                     ret.status_code,
                     str(ret.items()),
@@ -348,7 +310,7 @@ class SwiftConnector(object):
         return endpoint[self.endpoint_type], token
 
     def test_root_exists(self):
-        """Check that Swift container exist
+        """Check that Swift container exist.
 
         Returns: True if exist or None it not
         """
@@ -362,7 +324,7 @@ class SwiftConnector(object):
         return True
 
     def create_root(self):
-        """Create the Swift container
+        """Create the Swift container.
 
         Raises:
           SwiftException: if unable to create
@@ -375,7 +337,7 @@ class SwiftConnector(object):
                 )
 
     def get_container_objects(self):
-        """Retrieve objects list in a container
+        """Retrieve objects list in a container.
 
         Returns: A list of dict that describe objects
                  or None if container does not exist
@@ -393,7 +355,7 @@ class SwiftConnector(object):
         return json.loads(content)
 
     def get_object_stat(self, name):
-        """Retrieve object stat
+        """Retrieve object stat.
 
         Args:
           name: The object name
@@ -414,7 +376,7 @@ class SwiftConnector(object):
         return resp_headers
 
     def put_object(self, name, content):
-        """Put an object
+        """Put an object.
 
         Args:
           name: The object name
@@ -444,7 +406,7 @@ class SwiftConnector(object):
             )
 
     def get_object(self, name, range=None):
-        """Retrieve an object
+        """Retrieve an object.
 
         Args:
           name: The object name
@@ -471,7 +433,7 @@ class SwiftConnector(object):
         return BytesIO(content)
 
     def del_object(self, name):
-        """Delete an object
+        """Delete an object.
 
         Args:
           name: The object name
@@ -486,7 +448,7 @@ class SwiftConnector(object):
             )
 
     def del_root(self):
-        """Delete the root container by removing container content
+        """Delete the root container by removing container content.
 
         Raises:
           SwiftException: if unable to delete
@@ -500,18 +462,18 @@ class SwiftConnector(object):
             )
 
 
-class SwiftPackReader(object):
-    """A SwiftPackReader that mimic read and sync method
+class SwiftPackReader:
+    """A SwiftPackReader that mimic read and sync method.
 
     The reader allows to read a specified amount of bytes from
-    a given offset of a Swift object. A read offset is kept internaly.
+    a given offset of a Swift object. A read offset is kept internally.
     The reader will read from Swift a specified amount of data to complete
-    its internal buffer. chunk_length specifiy the amount of data
+    its internal buffer. chunk_length specify the amount of data
     to read from Swift.
     """
 
-    def __init__(self, scon, filename, pack_length):
-        """Initialize a SwiftPackReader
+    def __init__(self, scon, filename, pack_length) -> None:
+        """Initialize a SwiftPackReader.
 
         Args:
           scon: a `SwiftConnector` instance
@@ -531,11 +493,11 @@ class SwiftPackReader(object):
             self.buff_length = self.buff_length * 2
         offset = self.base_offset
         r = min(self.base_offset + self.buff_length, self.pack_length)
-        ret = self.scon.get_object(self.filename, range="%s-%s" % (offset, r))
+        ret = self.scon.get_object(self.filename, range=f"{offset}-{r}")
         self.buff = ret
 
     def read(self, length):
-        """Read a specified amount of Bytes form the pack object
+        """Read a specified amount of Bytes form the pack object.
 
         Args:
           length: amount of bytes to read
@@ -556,7 +518,7 @@ class SwiftPackReader(object):
         return data
 
     def seek(self, offset):
-        """Seek to a specified offset
+        """Seek to a specified offset.
 
         Args:
           offset: the offset to seek to
@@ -566,7 +528,7 @@ class SwiftPackReader(object):
         self.offset = 0
 
     def read_checksum(self):
-        """Read the checksum from the pack
+        """Read the checksum from the pack.
 
         Returns: the checksum bytestring
         """
@@ -580,8 +542,8 @@ class SwiftPackData(PackData):
     using the Range header feature of Swift.
     """
 
-    def __init__(self, scon, filename):
-        """Initialize a SwiftPackReader
+    def __init__(self, scon, filename) -> None:
+        """Initialize a SwiftPackReader.
 
         Args:
           scon: a `SwiftConnector` instance
@@ -625,10 +587,10 @@ class SwiftPack(Pack):
     PackData.
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         self.scon = kwargs["scon"]
         del kwargs["scon"]
-        super(SwiftPack, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._pack_info_path = self._basename + ".info"
         self._pack_info = None
         self._pack_info_load = lambda: load_pack_info(self._pack_info_path, self.scon)
@@ -644,19 +606,19 @@ class SwiftPack(Pack):
 
 
 class SwiftObjectStore(PackBasedObjectStore):
-    """A Swift Object Store
+    """A Swift Object Store.
 
     Allow to manage a bare Git repository from Openstack Swift.
     This object store only supports pack files and not loose objects.
     """
 
-    def __init__(self, scon):
+    def __init__(self, scon) -> None:
         """Open a Swift object store.
 
         Args:
           scon: A `SwiftConnector` instance
         """
-        super(SwiftObjectStore, self).__init__()
+        super().__init__()
         self.scon = scon
         self.root = self.scon.root
         self.pack_dir = posixpath.join(OBJECTDIR, PACKDIR)
@@ -677,22 +639,9 @@ class SwiftObjectStore(PackBasedObjectStore):
         return ret
 
     def _iter_loose_objects(self):
-        """Loose objects are not supported by this repository"""
+        """Loose objects are not supported by this repository."""
         return []
 
-    def iter_shas(self, finder):
-        """An iterator over pack's ObjectStore.
-
-        Returns: a `ObjectStoreIterator` or `GreenThreadsObjectStoreIterator`
-                 instance if gevent is enabled
-        """
-        shas = iter(finder.next, None)
-        return PackInfoObjectStoreIterator(self, shas, finder, self.scon.concurrency)
-
-    def find_missing_objects(self, *args, **kwargs):
-        kwargs["concurrency"] = self.scon.concurrency
-        return PackInfoMissingObjectFinder(self, *args, **kwargs)
-
     def pack_info_get(self, sha):
         for pack in self.packs:
             if sha in pack:
@@ -772,7 +721,7 @@ class SwiftObjectStore(PackBasedObjectStore):
         return None
 
     def add_thin_pack(self, read_all, read_some):
-        """Read a thin pack
+        """Read a thin pack.
 
         Read it from a stream and complete it in a temporary file.
         Then the pack and the corresponding index file are uploaded to Swift.
@@ -852,14 +801,14 @@ class SwiftObjectStore(PackBasedObjectStore):
 class SwiftInfoRefsContainer(InfoRefsContainer):
     """Manage references in info/refs object."""
 
-    def __init__(self, scon, store):
+    def __init__(self, scon, store) -> None:
         self.scon = scon
         self.filename = "info/refs"
         self.store = store
         f = self.scon.get_object(self.filename)
         if not f:
             f = BytesIO(b"")
-        super(SwiftInfoRefsContainer, self).__init__(f)
+        super().__init__(f)
 
     def _load_check_ref(self, name, old_ref):
         self._check_refname(name)
@@ -910,7 +859,7 @@ class SwiftInfoRefsContainer(InfoRefsContainer):
 
 
 class SwiftRepo(BaseRepo):
-    def __init__(self, root, conf):
+    def __init__(self, root, conf) -> None:
         """Init a Git bare Repository on top of a Swift container.
 
         References are managed in info/refs objects by
@@ -944,7 +893,7 @@ class SwiftRepo(BaseRepo):
         return False
 
     def _put_named_file(self, filename, contents):
-        """Put an object in a Swift container
+        """Put an object in a Swift container.
 
         Args:
           filename: the path to the object to put on Swift
@@ -976,7 +925,7 @@ class SwiftRepo(BaseRepo):
 
 
 class SwiftSystemBackend(Backend):
-    def __init__(self, logger, conf):
+    def __init__(self, logger, conf) -> None:
         self.conf = conf
         self.logger = logger
 
@@ -1065,7 +1014,7 @@ def main(argv=sys.argv):
     }
 
     if len(sys.argv) < 2:
-        print("Usage: %s <%s> [OPTIONS...]" % (sys.argv[0], "|".join(commands.keys())))
+        print("Usage: {} <{}> [OPTIONS...]".format(sys.argv[0], "|".join(commands.keys())))
         sys.exit(1)
 
     cmd = sys.argv[1]
