@@ -21,23 +21,22 @@
 
 import socket
 import threading
-
-from dulwich.tests import TestCase
-
 from io import StringIO
 from unittest import skipIf
 
+from dulwich.tests import TestCase
+
 try:
     import paramiko
 except ImportError:
     has_paramiko = False
 else:
     has_paramiko = True
-    from dulwich.contrib.paramiko_vendor import ParamikoSSHVendor
+    from .paramiko_vendor import ParamikoSSHVendor
 
     class Server(paramiko.ServerInterface):
-        """http://docs.paramiko.org/en/2.4/api/server.html"""
-        def __init__(self, commands, *args, **kwargs):
+        """http://docs.paramiko.org/en/2.4/api/server.html."""
+        def __init__(self, commands, *args, **kwargs) -> None:
             super().__init__(*args, **kwargs)
             self.commands = commands
 
