@@ -20,7 +20,7 @@
 # License, Version 2.0.
 #
 
-"""Start functional tests
+"""Start functional tests.
 
 A Swift installation must be available before
 starting those tests. The account and authentication method used
@@ -34,29 +34,23 @@ DULWICH_SWIFT_CFG=/tmp/conf.cfg PYTHONPATH=. python -m unittest \
 """
 
 import os
-import unittest
-import tempfile
 import shutil
+import tempfile
+import unittest
 
 import gevent
 from gevent import monkey
 
 monkey.patch_all()
 
-from dulwich import (  # noqa:E402
-    server,
-    repo,
-    index,
-    client,
-    objects,
-)
+from dulwich import client, index, objects, repo, server  # noqa:E402
 from dulwich.contrib import swift  # noqa:E402
 
 
 class DulwichServer:
-    """Start the TCPGitServer with Swift backend"""
+    """Start the TCPGitServer with Swift backend."""
 
-    def __init__(self, backend, port):
+    def __init__(self, backend, port) -> None:
         self.port = port
         self.backend = backend
 
