@@ -24,17 +24,13 @@ These patches are basically unified diffs with some extra metadata tacked
 on.
 """
 
-from difflib import SequenceMatcher
 import email.parser
 import time
-from typing import Union, TextIO, BinaryIO, Optional
+from difflib import SequenceMatcher
+from typing import BinaryIO, Optional, TextIO, Union
 
-from dulwich.objects import (
-    Blob,
-    Commit,
-    S_ISGITLINK,
-)
-from dulwich.pack import ObjectContainer
+from .objects import S_ISGITLINK, Blob, Commit
+from .pack import ObjectContainer
 
 FIRST_FEW_BYTES = 8000
 
@@ -45,6 +41,7 @@ def write_commit_patch(f, commit, contents, progress, version=None, encoding=Non
     Args:
       commit: Commit object
       progress: Tuple with current patch number and total.
+
     Returns:
       tuple with filename and contents
     """
@@ -105,7 +102,7 @@ def get_summary(commit):
 
 #  Unified Diff
 def _format_range_unified(start, stop):
-    'Convert range to the "ed" format'
+    """Convert range to the "ed" format."""
     # Per the diff spec at http://www.unix.org/single_unix_specification/
     beginning = start + 1  # lines start numbering with one
     length = stop - start
