@@ -35,15 +35,10 @@ import subprocess
 import sys
 import tempfile
 
-
 # If Python itself provides an exception, use that
 import unittest
-from unittest import (  # noqa: F401
-    SkipTest,
-    TestCase as _TestCase,
-    skipIf,
-    expectedFailure,
-)
+from unittest import SkipTest, expectedFailure, skipIf
+from unittest import TestCase as _TestCase  # noqa: F401
 
 
 class TestCase(_TestCase):
@@ -163,9 +158,6 @@ def tutorial_test_suite():
     import dulwich.client
     import dulwich.config
     import dulwich.index
-    import dulwich.reflog
-    import dulwich.repo
-    import dulwich.server
     import dulwich.patch  # noqa: F401
 
     tutorial = [
@@ -176,17 +168,35 @@ def tutorial_test_suite():
         "remote",
         "conclusion",
     ]
-    tutorial_files = ["../../docs/tutorial/%s.txt" % name for name in tutorial]
+    tutorial_files = [f"../../docs/tutorial/{name}.txt" for name in tutorial]
+
+    to_restore = []
+
+    def overrideEnv(name, value):
+        oldval = os.environ.get(name)
+        if value is not None:
+            os.environ[name] = value
+        else:
+            del os.environ[name]
+        to_restore.append((name, oldval))
 
     def setup(test):
         test.__old_cwd = os.getcwd()
         test.tempdir = tempfile.mkdtemp()
         test.globs.update({"tempdir": test.tempdir})
         os.chdir(test.tempdir)
+        overrideEnv("HOME", "/nonexistent")
+        overrideEnv("GIT_CONFIG_NOSYSTEM", "1")
 
     def teardown(test):
         os.chdir(test.__old_cwd)
         shutil.rmtree(test.tempdir)
+        for name, oldval in to_restore:
+            if oldval is not None:
+                os.environ[name] = oldval
+            else:
+                del os.environ[name]
+        to_restore.clear()
 
     return doctest.DocFileSuite(
         module_relative=True,
