@@ -21,7 +21,7 @@
 """Compatibility tests between the Dulwich client and the cgit server."""
 
 import copy
-from io import BytesIO
+import http.server
 import os
 import select
 import signal
@@ -31,33 +31,22 @@ import sys
 import tarfile
 import tempfile
 import threading
-
+from contextlib import suppress
+from io import BytesIO
 from urllib.parse import unquote
 
-import http.server
+from dulwich import client, file, index, objects, protocol, repo
+from dulwich.tests import SkipTest, expectedFailure
 
-from dulwich import (
-    client,
-    file,
-    index,
-    protocol,
-    objects,
-    repo,
-)
-from dulwich.tests import (
-    SkipTest,
-    expectedFailure,
-)
-from dulwich.tests.compat.utils import (
+from .utils import (
+    _DEFAULT_GIT,
     CompatTestCase,
     check_for_daemon,
     import_repo_to_dir,
     rmtree_ro,
     run_git_or_fail,
-    _DEFAULT_GIT,
 )
 
-
 if sys.platform == "win32":
     import ctypes
 
@@ -404,11 +393,9 @@ class DulwichTCPClientTest(CompatTestCase, DulwichClientTestBase):
             ctypes.windll.kernel32.TerminateProcess(handle, -1)
             ctypes.windll.kernel32.CloseHandle(handle)
         else:
-            try:
+            with suppress(OSError):
                 os.kill(pid, signal.SIGKILL)
                 os.unlink(self.pidfile)
-            except OSError:
-                pass
         self.process.wait()
         self.process.stdout.close()
         self.process.stderr.close()
@@ -640,13 +627,13 @@ class HTTPGitServer(http.server.HTTPServer):
 
     allow_reuse_address = True
 
-    def __init__(self, server_address, root_path):
+    def __init__(self, server_address, root_path) -> None:
         http.server.HTTPServer.__init__(self, server_address, GitHTTPRequestHandler)
         self.root_path = root_path
         self.server_name = "localhost"
 
     def get_url(self):
-        return "http://{}:{}/".format(self.server_name, self.server_port)
+        return f"http://{self.server_name}:{self.server_port}/"
 
 
 class DulwichHttpClientTest(CompatTestCase, DulwichClientTestBase):
