@@ -25,23 +25,15 @@ Warning: these tests should be fairly stable, but when writing/debugging new
     Ctrl-C'ed. On POSIX systems, you can kill the tests with Ctrl-Z, "kill %".
 """
 
-import threading
 import os
 import sys
+import threading
 
-from dulwich.server import (
-    DictBackend,
-    TCPGitServer,
-)
 from dulwich.tests import skipIf
-from dulwich.tests.compat.server_utils import (
-    ServerTests,
-    NoSideBand64kReceivePackHandler,
-)
-from dulwich.tests.compat.utils import (
-    CompatTestCase,
-    require_git_version,
-)
+
+from ...server import DictBackend, TCPGitServer
+from .server_utils import NoSideBand64kReceivePackHandler, ServerTests
+from .utils import CompatTestCase, require_git_version
 
 
 @skipIf(sys.platform == "win32", "Broken on windows, with very long fail time.")
