@@ -32,13 +32,10 @@ import tempfile
 import time
 from typing import Tuple
 
-from dulwich.repo import Repo
-from dulwich.protocol import TCP_GIT_PORT
+from dulwich.tests import SkipTest, TestCase
 
-from dulwich.tests import (
-    SkipTest,
-    TestCase,
-)
+from ...protocol import TCP_GIT_PORT
+from ...repo import Repo
 
 _DEFAULT_GIT = "git"
 _VERSION_LEN = 4
@@ -87,6 +84,7 @@ def require_git_version(required_version, git_path=_DEFAULT_GIT):
         sub-point); omitted components default to 0.
       git_path: Path to the git executable; defaults to the version in
         the system path.
+
     Raises:
       ValueError: if the required version tuple has too many parts.
       SkipTest: if no suitable git version was found at the given path.
@@ -94,7 +92,7 @@ def require_git_version(required_version, git_path=_DEFAULT_GIT):
     found_version = git_version(git_path=git_path)
     if found_version is None:
         raise SkipTest(
-            "Test requires git >= {}, but c git not found".format(required_version)
+            f"Test requires git >= {required_version}, but c git not found"
         )
 
     if len(required_version) > _VERSION_LEN:
@@ -112,7 +110,7 @@ def require_git_version(required_version, git_path=_DEFAULT_GIT):
         required_version = ".".join(map(str, required_version))
         found_version = ".".join(map(str, found_version))
         raise SkipTest(
-            "Test requires git >= {}, found {}".format(required_version, found_version)
+            f"Test requires git >= {required_version}, found {found_version}"
         )
 
 
@@ -135,10 +133,10 @@ def run_git(
     Returns: A tuple of (returncode, stdout contents, stderr contents).
         If capture_stdout is False, None will be returned as stdout contents.
         If capture_stderr is False, None will be returned as stderr contents.
+
     Raises:
       OSError: if the git executable was not found.
     """
-
     env = popen_kwargs.pop("env", {})
     env["LC_ALL"] = env["LANG"] = "C"
     env["PATH"] = os.getenv("PATH")
