@@ -18,78 +18,55 @@
 # License, Version 2.0.
 #
 
-from io import BytesIO
 import base64
 import os
-import sys
 import shutil
+import sys
 import tempfile
 import warnings
-
-from urllib.parse import (
-    quote as urlquote,
-    urlparse,
-)
-
+from io import BytesIO
+from typing import Dict
 from unittest.mock import patch
+from urllib.parse import quote as urlquote
+from urllib.parse import urlparse
 
 import dulwich
-from dulwich import (
-    client,
-)
-from dulwich.client import (
+from dulwich import client
+from dulwich.tests import TestCase, skipIf
+
+from ..client import (
+    FetchPackResult,
+    GitProtocolError,
+    HangupException,
+    HttpGitClient,
     InvalidWants,
     LocalGitClient,
-    TraditionalGitClient,
-    TCPGitClient,
-    SSHGitClient,
-    HttpGitClient,
-    FetchPackResult,
+    PLinkSSHVendor,
     ReportStatusParser,
     SendPackError,
+    SSHGitClient,
     StrangeHostname,
     SubprocessSSHVendor,
-    PLinkSSHVendor,
-    HangupException,
-    GitProtocolError,
+    TCPGitClient,
+    TraditionalGitClient,
+    _remote_error_from_stderr,
     check_wants,
     default_urllib3_manager,
     get_credentials_from_store,
     get_transport_and_path,
     get_transport_and_path_from_url,
     parse_rsync_url,
-    _remote_error_from_stderr,
-)
-from dulwich.config import (
-    ConfigDict,
-)
-from dulwich.tests import (
-    TestCase,
-)
-from dulwich.protocol import (
-    TCP_GIT_PORT,
-    Protocol,
-)
-from dulwich.pack import (
-    pack_objects_to_data,
-    write_pack_data,
-    write_pack_objects,
-)
-from dulwich.objects import Commit, Tree
-from dulwich.repo import (
-    MemoryRepo,
-    Repo,
-)
-from dulwich.tests import skipIf
-from dulwich.tests.utils import (
-    open_repo,
-    tear_down_repo,
-    setup_warning_catcher,
 )
+from ..config import ConfigDict
+from ..objects import Commit, Tree
+from ..pack import pack_objects_to_data, write_pack_data, write_pack_objects
+from ..protocol import TCP_GIT_PORT, Protocol
+from ..repo import MemoryRepo, Repo
+from .utils import open_repo, setup_warning_catcher, tear_down_repo
 
 
 class DummyClient(TraditionalGitClient):
-    def __init__(self, can_read, read, write):
+    def __init__(self, can_read, read, write) -> None:
         self.can_read = can_read
         self.read = read
         self.write = write
@@ -100,7 +77,7 @@ class DummyClient(TraditionalGitClient):
 
 
 class DummyPopen:
-    def __init__(self, *args, **kwards):
+    def __init__(self, *args, **kwards) -> None:
         self.stdin = BytesIO(b"stdin")
         self.stdout = BytesIO(b"stdout")
         self.stderr = BytesIO(b"stderr")
@@ -718,7 +695,7 @@ class TestGetTransportAndPathFromUrl(TestCase):
 
 
 class TestSSHVendor:
-    def __init__(self):
+    def __init__(self) -> None:
         self.host = None
         self.command = ""
         self.username = None
@@ -1023,7 +1000,7 @@ class HttpGitClientTests(TestCase):
 
         c = HttpGitClient(url, config=None, username="user")
         self.assertEqual("user", c._username)
-        self.assertIs(c._password, None)
+        self.assertIsNone(c._password)
 
         basic_auth = c.pool_manager.headers["authorization"]
         auth_string = b"user:"
@@ -1069,7 +1046,7 @@ class HttpGitClientTests(TestCase):
         self.assertEqual(original_password, c._password)
 
         basic_auth = c.pool_manager.headers["authorization"]
-        auth_string = "{}:{}".format(original_username, original_password)
+        auth_string = f"{original_username}:{original_password}"
         b64_credentials = base64.b64encode(auth_string.encode("latin1"))
         expected_basic_auth = "Basic %s" % b64_credentials.decode("latin1")
         self.assertEqual(basic_auth, expected_basic_auth)
@@ -1079,6 +1056,7 @@ class HttpGitClientTests(TestCase):
 
         test_data = {
             "https://gitlab.com/inkscape/inkscape/": {
+                "location": "https://gitlab.com/inkscape/inkscape.git/",
                 "redirect_url": "https://gitlab.com/inkscape/inkscape.git/",
                 "refs_data": (
                     b"001e# service=git-upload-pack\n00000032"
@@ -1087,6 +1065,7 @@ class HttpGitClientTests(TestCase):
                 ),
             },
             "https://github.com/jelmer/dulwich/": {
+                "location": "https://github.com/jelmer/dulwich/",
                 "redirect_url": "https://github.com/jelmer/dulwich/",
                 "refs_data": (
                     b"001e# service=git-upload-pack\n00000032"
@@ -1094,6 +1073,16 @@ class HttpGitClientTests(TestCase):
                     b"HEAD\n0000"
                 ),
             },
+            # check for absolute-path URI reference as location
+            "https://codeberg.org/ashwinvis/radicale-sh.git/": {
+                "location": "/ashwinvis/radicale-auth-sh/",
+                "redirect_url": "https://codeberg.org/ashwinvis/radicale-auth-sh/",
+                "refs_data": (
+                    b"001e# service=git-upload-pack\n00000032"
+                    b"470f8603768b608fc988675de2fae8f963c21158 "
+                    b"HEAD\n0000"
+                ),
+            },
         }
 
         tail = "info/refs?service=git-upload-pack"
@@ -1101,12 +1090,12 @@ class HttpGitClientTests(TestCase):
         # we need to mock urllib3.PoolManager as this test will fail
         # otherwise without an active internet connection
         class PoolManagerMock:
-            def __init__(self):
-                self.headers = {}
+            def __init__(self) -> None:
+                self.headers: Dict[str, str] = {}
 
             def request(self, method, url, fields=None, headers=None, redirect=True, preload_content=True):
                 base_url = url[: -len(tail)]
-                redirect_base_url = test_data[base_url]["redirect_url"]
+                redirect_base_url = test_data[base_url]["location"]
                 redirect_url = redirect_base_url + tail
                 headers = {
                     "Content-Type": "application/x-git-upload-pack-advertisement"
@@ -1120,8 +1109,9 @@ class HttpGitClientTests(TestCase):
                     request_url = url
                     if redirect_base_url != base_url:
                         body = b""
-                        headers["location"] = redirect_url
+                        headers["location"] = test_data[base_url]["location"]
                         status = 301
+
                 return HTTPResponse(
                     body=BytesIO(body),
                     headers=headers,
@@ -1144,16 +1134,41 @@ class HttpGitClientTests(TestCase):
 
             # check expected behavior of urllib3
             redirect_location = resp.get_redirect_location()
+
             if resp.status == 200:
                 self.assertFalse(redirect_location)
 
             if redirect_location:
                 # check that url redirection has been correctly detected
-                self.assertEqual(processed_url, redirect_location[: -len(tail)])
+                self.assertEqual(processed_url, test_data[base_url]["redirect_url"])
             else:
                 # check also the no redirection case
                 self.assertEqual(processed_url, base_url)
 
+    def test_smart_request_content_type_with_directive_check(self):
+        from urllib3.response import HTTPResponse
+
+        # we need to mock urllib3.PoolManager as this test will fail
+        # otherwise without an active internet connection
+        class PoolManagerMock:
+            def __init__(self) -> None:
+                self.headers: Dict[str, str] = {}
+
+            def request(self, method, url, fields=None, headers=None, redirect=True, preload_content=True):
+                return HTTPResponse(
+                    headers={
+                        "Content-Type": "application/x-git-upload-pack-result; charset=utf-8"
+                    },
+                    request_method=method,
+                    request_url=url,
+                    preload_content=preload_content,
+                    status=200,
+                )
+
+        clone_url = "https://hacktivis.me/git/blog.git/"
+        client = HttpGitClient(clone_url, pool_manager=PoolManagerMock(), config=None)
+        self.assertTrue(client._smart_request("git-upload-pack", clone_url, data=None))
+
 
 class TCPGitClientTests(TestCase):
     def test_get_url(self):
@@ -1523,11 +1538,11 @@ class PLinkSSHVendorTests(TestCase):
         )
 
         for w in warnings_list:
-            if type(w) == type(expected_warning) and w.args == expected_warning.args:
+            if type(w) is type(expected_warning) and w.args == expected_warning.args:
                 break
         else:
             raise AssertionError(
-                "Expected warning {!r} not in {!r}".format(expected_warning, warnings_list)
+                f"Expected warning {expected_warning!r} not in {warnings_list!r}"
             )
 
         args = command.proc.args
@@ -1568,11 +1583,11 @@ class PLinkSSHVendorTests(TestCase):
         )
 
         for w in warnings_list:
-            if type(w) == type(expected_warning) and w.args == expected_warning.args:
+            if type(w) is type(expected_warning) and w.args == expected_warning.args:
                 break
         else:
             raise AssertionError(
-                "Expected warning {!r} not in {!r}".format(expected_warning, warnings_list)
+                f"Expected warning {expected_warning!r} not in {warnings_list!r}"
             )
 
         args = command.proc.args
