@@ -26,20 +26,19 @@ from io import BytesIO
 from unittest import skipIf
 from unittest.mock import patch
 
-from dulwich.config import (
+from dulwich.tests import TestCase
+
+from ..config import (
     ConfigDict,
     ConfigFile,
     StackedConfig,
     _check_section_name,
     _check_variable_name,
-    _format_string,
     _escape_value,
+    _format_string,
     _parse_string,
-    parse_submodules,
     apply_instead_of,
-)
-from dulwich.tests import (
-    TestCase,
+    parse_submodules,
 )
 
 
@@ -312,7 +311,7 @@ class StackedConfigTests(TestCase):
 
     @skipIf(sys.platform != "win32", "Windows specific config location.")
     def test_windows_config_from_path(self):
-        from dulwich.config import get_win_system_paths
+        from ..config import get_win_system_paths
 
         install_dir = os.path.join("C:", "foo", "Git")
         self.overrideEnv("PATH", os.path.join(install_dir, "cmd"))
@@ -330,7 +329,7 @@ class StackedConfigTests(TestCase):
     def test_windows_config_from_reg(self):
         import winreg
 
-        from dulwich.config import get_win_system_paths
+        from ..config import get_win_system_paths
 
         self.overrideEnv("PATH", None)
         install_dir = os.path.join("C:", "foo", "Git")
