@@ -20,21 +20,16 @@
 """Tests for executing hooks."""
 
 import os
-import stat
 import shutil
+import stat
 import sys
 import tempfile
 
 from dulwich import errors
-
-from dulwich.hooks import (
-    PreCommitShellHook,
-    PostCommitShellHook,
-    CommitMsgShellHook,
-)
-
 from dulwich.tests import TestCase
 
+from ..hooks import CommitMsgShellHook, PostCommitShellHook, PreCommitShellHook
+
 
 class ShellHookTests(TestCase):
     def setUp(self):
