@@ -20,14 +20,15 @@
 
 """Tests for ignore files."""
 
-from io import BytesIO
 import os
 import re
 import shutil
 import tempfile
+from io import BytesIO
+
 from dulwich.tests import TestCase
 
-from dulwich.ignore import (
+from ..ignore import (
     IgnoreFilter,
     IgnoreFilterManager,
     IgnoreFilterStack,
@@ -36,8 +37,7 @@ from dulwich.ignore import (
     read_ignore_patterns,
     translate,
 )
-from dulwich.repo import Repo
-
+from ..repo import Repo
 
 POSITIVE_MATCH_TESTS = [
     (b"foo.c", b"*.c"),
@@ -98,8 +98,7 @@ class TranslateTests(TestCase):
             self.assertEqual(
                 regex,
                 translate(pattern),
-                "orig pattern: %r, regex: %r, expected: %r"
-                % (pattern, translate(pattern), regex),
+                f"orig pattern: {pattern!r}, regex: {translate(pattern)!r}, expected: {regex!r}",
             )
 
 
@@ -133,14 +132,14 @@ class MatchPatternTests(TestCase):
         for (path, pattern) in POSITIVE_MATCH_TESTS:
             self.assertTrue(
                 match_pattern(path, pattern),
-                "path: {!r}, pattern: {!r}".format(path, pattern),
+                f"path: {path!r}, pattern: {pattern!r}",
             )
 
     def test_no_matches(self):
         for (path, pattern) in NEGATIVE_MATCH_TESTS:
             self.assertFalse(
                 match_pattern(path, pattern),
-                "path: {!r}, pattern: {!r}".format(path, pattern),
+                f"path: {path!r}, pattern: {pattern!r}",
             )
 
 
