@@ -18,19 +18,11 @@
 # License, Version 2.0.
 #
 
-from dulwich.object_store import (
-    MemoryObjectStore,
-    MissingObjectFinder,
-)
-from dulwich.objects import (
-    Blob,
-)
 from dulwich.tests import TestCase
-from dulwich.tests.utils import (
-    make_object,
-    make_tag,
-    build_commit_graph,
-)
+
+from ..object_store import MemoryObjectStore, MissingObjectFinder
+from ..objects import Blob
+from .utils import build_commit_graph, make_object, make_tag
 
 
 class MissingObjectFinderTest(TestCase):
@@ -47,14 +39,14 @@ class MissingObjectFinderTest(TestCase):
             self.assertIn(
                 sha,
                 expected,
-                "({},{}) erroneously reported as missing".format(sha, path)
+                f"({sha},{path}) erroneously reported as missing"
             )
             expected.remove(sha)
 
         self.assertEqual(
             len(expected),
             0,
-            "some objects are not reported as missing: {}".format(expected),
+            f"some objects are not reported as missing: {expected}",
         )
 
 
@@ -104,14 +96,14 @@ class MOFLinearRepoTest(MissingObjectFinderTest):
         self.assertMissingMatch([self.cmt(1).id], [self.cmt(3).id], self.missing_1_3)
 
     def test_bogus_haves(self):
-        """Ensure non-existent SHA in haves are tolerated"""
+        """Ensure non-existent SHA in haves are tolerated."""
         bogus_sha = self.cmt(2).id[::-1]
         haves = [self.cmt(1).id, bogus_sha]
         wants = [self.cmt(3).id]
         self.assertMissingMatch(haves, wants, self.missing_1_3)
 
     def test_bogus_wants_failure(self):
-        """Ensure non-existent SHA in wants are not tolerated"""
+        """Ensure non-existent SHA in wants are not tolerated."""
         bogus_sha = self.cmt(2).id[::-1]
         haves = [self.cmt(1).id]
         wants = [self.cmt(3).id, bogus_sha]
