@@ -21,54 +21,42 @@
 """Tests for the object store interface."""
 
 
-from contextlib import closing
-from io import BytesIO
-from unittest import skipUnless
 import os
 import shutil
 import stat
 import sys
 import tempfile
+from contextlib import closing
+from io import BytesIO
+from unittest import skipUnless
 
-from dulwich.index import (
-    commit_tree,
-)
-from dulwich.errors import (
-    NotTreeError,
-)
-from dulwich.objects import (
-    sha_to_hex,
-    Blob,
-    Tree,
-    TreeEntry,
-    EmptyFileException,
-    SubmoduleEncountered,
-    S_IFGITLINK,
-)
-from dulwich.object_store import (
+from dulwich.tests import TestCase
+
+from ..errors import NotTreeError
+from ..index import commit_tree
+from ..object_store import (
     DiskObjectStore,
     MemoryObjectStore,
-    OverlayObjectStore,
     ObjectStoreGraphWalker,
+    OverlayObjectStore,
     commit_tree_changes,
     iter_tree_contents,
     peel_sha,
     read_packs_file,
     tree_lookup_path,
 )
-from dulwich.pack import (
-    REF_DELTA,
-    write_pack_objects,
-)
-from dulwich.protocol import DEPTH_INFINITE
-from dulwich.tests import (
-    TestCase,
-)
-from dulwich.tests.utils import (
-    make_object,
-    make_tag,
-    build_pack,
+from ..objects import (
+    S_IFGITLINK,
+    Blob,
+    EmptyFileException,
+    SubmoduleEncountered,
+    Tree,
+    TreeEntry,
+    sha_to_hex,
 )
+from ..pack import REF_DELTA, write_pack_objects
+from ..protocol import DEPTH_INFINITE
+from .utils import build_pack, make_object, make_tag
 
 try:
     from unittest.mock import patch
@@ -453,7 +441,7 @@ class DiskObjectStoreTests(PackBasedObjectStoreTests, TestCase):
         self.assertEqual(oct(mode), packmode)
 
     def test_corrupted_object_raise_exception(self):
-        """Corrupted sha1 disk file should raise specific exception"""
+        """Corrupted sha1 disk file should raise specific exception."""
         self.store.add_object(testobject)
         self.assertEqual(
             (Blob.type_num, b"yummy data"), self.store.get_raw(testobject.id)
