@@ -23,49 +23,39 @@
 # TODO: Round-trip parse-serialize-parse and serialize-parse-serialize tests.
 
 
-from io import BytesIO
 import datetime
-from itertools import (
-    permutations,
-)
 import os
 import stat
 from contextlib import contextmanager
+from io import BytesIO
+from itertools import permutations
 
-from dulwich.errors import (
-    ObjectFormatException,
-)
-from dulwich.objects import (
+from dulwich.tests import TestCase
+
+from ..errors import ObjectFormatException
+from ..objects import (
+    MAX_TIME,
     Blob,
-    Tree,
     Commit,
     ShaFile,
     Tag,
+    Tree,
     TreeEntry,
-    format_timezone,
-    hex_to_sha,
-    sha_to_hex,
-    hex_to_filename,
+    _parse_tree_py,
+    _sorted_tree_items_py,
     check_hexsha,
     check_identity,
+    format_timezone,
+    hex_to_filename,
+    hex_to_sha,
     object_class,
     parse_timezone,
-    pretty_format_tree_entry,
     parse_tree,
-    _parse_tree_py,
+    pretty_format_tree_entry,
+    sha_to_hex,
     sorted_tree_items,
-    _sorted_tree_items_py,
-    MAX_TIME,
-)
-from dulwich.tests import (
-    TestCase,
-)
-from dulwich.tests.utils import (
-    make_commit,
-    make_object,
-    functest_builder,
-    ext_functest_builder,
 )
+from .utils import ext_functest_builder, functest_builder, make_commit, make_object
 
 a_sha = b"6f670c0fb53f9463760b7295fbb814e965fb20c8"
 b_sha = b"2969be3e8ee1c0222396a5611407e4769f14e54b"
@@ -83,14 +73,14 @@ class TestHexToSha(TestCase):
 
 
 class BlobReadTests(TestCase):
-    """Test decompression of blobs"""
+    """Test decompression of blobs."""
 
     def get_sha_file(self, cls, base, sha):
         dir = os.path.join(os.path.dirname(__file__), "..", "..", "testdata", base)
         return cls.from_path(hex_to_filename(dir, sha))
 
     def get_blob(self, sha):
-        """Return the blob named sha from the test data dir"""
+        """Return the blob named sha from the test data dir."""
         return self.get_sha_file(Blob, "blobs", sha)
 
     def get_tree(self, sha):
@@ -624,7 +614,7 @@ class CommitParseTests(ShaFileCheckTests):
 
     def test_custom(self):
         c = Commit.from_string(self.make_commit_text(extra={b"extra-field": b"data"}))
-        self.assertEqual([(b"extra-field", b"data")], c.extra)
+        self.assertEqual([(b"extra-field", b"data")], c._extra)
 
     def test_encoding(self):
         c = Commit.from_string(self.make_commit_text(encoding=b"UTF-8"))
@@ -691,7 +681,7 @@ class CommitParseTests(ShaFileCheckTests):
         )
 
     def test_check_commit_with_overflow_date(self):
-        """Date with overflow should raise an ObjectFormatException when checked"""
+        """Date with overflow should raise an ObjectFormatException when checked."""
         identity_with_wrong_time = (
             b"Igor Sysoev <igor@sysoev.ru> 18446743887488505614 +42707004"
         )
@@ -712,7 +702,7 @@ class CommitParseTests(ShaFileCheckTests):
                 commit.check()
 
     def test_mangled_author_line(self):
-        """Mangled author line should successfully parse"""
+        """Mangled author line should successfully parse."""
         author_line = (
             b'Karl MacMillan <kmacmill@redhat.com> <"Karl MacMillan '
             b'<kmacmill@redhat.com>"> 1197475547 -0500'
@@ -757,7 +747,7 @@ foo
 """
         )
         self.assertEqual(b"foo\n", c.message)
-        self.assertEqual([], c.extra)
+        self.assertEqual([], c._extra)
         self.assertEqual(
             b"""-----BEGIN PGP SIGNATURE-----
 Version: GnuPG v1
@@ -801,7 +791,7 @@ gpgsig -----BEGIN PGP SIGNATURE-----
 3.3.0 version bump and docs
 """
         )
-        self.assertEqual([], c.extra)
+        self.assertEqual([], c._extra)
         self.assertEqual(
             b"""\
 -----BEGIN PGP SIGNATURE-----
@@ -1142,8 +1132,8 @@ class TagParseTests(ShaFileCheckTests):
         )
 
     def test_check_tag_with_overflow_time(self):
-        """Date with overflow should raise an ObjectFormatException when checked"""
-        author = "Some Dude <some@dude.org> {} +0000".format(MAX_TIME + 1)
+        """Date with overflow should raise an ObjectFormatException when checked."""
+        author = f"Some Dude <some@dude.org> {MAX_TIME + 1} +0000"
         tag = Tag.from_string(self.make_tag_text(tagger=(author.encode())))
         with self.assertRaises(ObjectFormatException):
             tag.check()
