@@ -22,18 +22,16 @@
 
 from io import BytesIO
 
-from dulwich.objects import ZERO_SHA
-from dulwich.reflog import (
+from dulwich.tests import TestCase
+
+from ..objects import ZERO_SHA
+from ..reflog import (
     drop_reflog_entry,
     format_reflog_line,
     parse_reflog_line,
     read_reflog,
 )
 
-from dulwich.tests import (
-    TestCase,
-)
-
 
 class ReflogLineTests(TestCase):
     def test_format(self):
