@@ -29,31 +29,21 @@ import sys
 import tempfile
 import warnings
 
-from dulwich import errors
-from dulwich import porcelain
-from dulwich.object_store import (
-    tree_lookup_path,
-)
-from dulwich import objects
-from dulwich.config import Config
-from dulwich.errors import NotGitRepository
-from dulwich.repo import (
+from dulwich import errors, objects, porcelain
+from dulwich.tests import TestCase, skipIf
+
+from ..config import Config
+from ..errors import NotGitRepository
+from ..object_store import tree_lookup_path
+from ..repo import (
     InvalidUserIdentity,
-    Repo,
     MemoryRepo,
-    check_user_identity,
-    UnsupportedVersion,
+    Repo,
     UnsupportedExtension,
+    UnsupportedVersion,
+    check_user_identity,
 )
-from dulwich.tests import (
-    TestCase,
-    skipIf,
-)
-from dulwich.tests.utils import (
-    open_repo,
-    tear_down_repo,
-    setup_warning_catcher,
-)
+from .utils import open_repo, setup_warning_catcher, tear_down_repo
 
 missing_sha = b"b91fa4d900e17e99b433218e988c4eb4a3e9a097"
 
@@ -139,6 +129,12 @@ class MemoryRepoTests(TestCase):
         r.set_description(description)
         self.assertEqual(description, r.get_description())
 
+    def test_pull_into(self):
+        r = MemoryRepo.init_bare([], {})
+        repo = open_repo("a.git")
+        self.addCleanup(tear_down_repo, repo)
+        repo.fetch(r)
+
 
 class RepositoryRootTests(TestCase):
     def mkdtemp(self):
@@ -439,6 +435,43 @@ class RepositoryRootTests(TestCase):
         self.addCleanup(shutil.rmtree, tmp_dir)
         r.clone(tmp_dir, mkdir=False, bare=True)
 
+    def test_reset_index_symlink_enabled(self):
+        if sys.platform == 'win32':
+            self.skipTest("symlinks are not supported on Windows")
+        tmp_dir = self.mkdtemp()
+        self.addCleanup(shutil.rmtree, tmp_dir)
+
+        o = Repo.init(os.path.join(tmp_dir, "s"), mkdir=True)
+        os.symlink("foo", os.path.join(tmp_dir, "s", "bar"))
+        o.stage("bar")
+        o.do_commit(b"add symlink")
+
+        t = o.clone(os.path.join(tmp_dir, "t"), symlinks=True)
+        o.close()
+        bar_path = os.path.join(tmp_dir, 't', 'bar')
+        if sys.platform == 'win32':
+            with open(bar_path) as f:
+                self.assertEqual('foo', f.read())
+        else:
+            self.assertEqual('foo', os.readlink(bar_path))
+        t.close()
+
+    def test_reset_index_symlink_disabled(self):
+        tmp_dir = self.mkdtemp()
+        self.addCleanup(shutil.rmtree, tmp_dir)
+
+        o = Repo.init(os.path.join(tmp_dir, "s"), mkdir=True)
+        o.close()
+        os.symlink("foo", os.path.join(tmp_dir, "s", "bar"))
+        o.stage("bar")
+        o.do_commit(b"add symlink")
+
+        t = o.clone(os.path.join(tmp_dir, "t"), symlinks=False)
+        with open(os.path.join(tmp_dir, "t", 'bar')) as f:
+            self.assertEqual('foo', f.read())
+
+        t.close()
+
     def test_clone_bare(self):
         r = self.open_repo("a.git")
         tmp_dir = self.mkdtemp()
@@ -537,13 +570,11 @@ class RepositoryRootTests(TestCase):
         self.assertIsInstance(r.get_config_stack(), Config)
 
     def test_common_revisions(self):
-        """
-        This test demonstrates that ``find_common_revisions()`` actually
+        """This test demonstrates that ``find_common_revisions()`` actually
         returns common heads, not revisions; dulwich already uses
         ``find_common_revisions()`` in such a manner (see
         ``Repo.find_objects()``).
         """
-
         expected_shas = {b"60dacdc733de308bb77bb76ce0fb0f9b44c9769e"}
 
         # Source for objects.
@@ -811,11 +842,11 @@ exit 1
             "non-zero status 1",
         )
         for w in warnings_list:
-            if type(w) == type(expected_warning) and w.args == expected_warning.args:
+            if type(w) is type(expected_warning) and w.args == expected_warning.args:
                 break
         else:
             raise AssertionError(
-                "Expected warning {!r} not in {!r}".format(expected_warning, warnings_list)
+                f"Expected warning {expected_warning!r} not in {warnings_list!r}"
             )
         self.assertEqual([commit_sha], r[commit_sha2].parents)
 
@@ -1097,12 +1128,25 @@ class BuildRepoRootTests(TestCase):
         c.write_to_path()
         Repo(self._repo_dir)
 
-    def test_repositoryformatversion_1_extension(self):
+    def test_worktreeconfig_extension(self):
         r = self._repo
         c = r.get_config()
         c.set(("core",), "repositoryformatversion", "1")
         c.set(("extensions", ), "worktreeconfig", True)
         c.write_to_path()
+        c = r.get_worktree_config()
+        c.set(("user",), "repositoryformatversion", "1")
+        c.set((b"user",), b"name", b"Jelmer")
+        c.write_to_path()
+        cs = r.get_config_stack()
+        self.assertEqual(cs.get(("user", ), "name"), b"Jelmer")
+
+    def test_repositoryformatversion_1_extension(self):
+        r = self._repo
+        c = r.get_config()
+        c.set(("core",), "repositoryformatversion", "1")
+        c.set(("extensions", ), "unknownextension", True)
+        c.write_to_path()
         self.assertRaises(UnsupportedExtension, Repo, self._repo_dir)
 
     def test_commit_encoding_from_config(self):
