@@ -20,52 +20,42 @@
 
 """Tests for the smart protocol server."""
 
-from io import BytesIO
 import os
 import shutil
-import tempfile
-
 import sys
+import tempfile
+from io import BytesIO
+from typing import Dict, List
 
-from dulwich.errors import (
+from dulwich.tests import TestCase
+
+from ..errors import (
     GitProtocolError,
+    HangupException,
     NotGitRepository,
     UnexpectedCommandError,
-    HangupException,
 )
-from dulwich.objects import Tree
-from dulwich.object_store import (
-    MemoryObjectStore,
-)
-from dulwich.repo import (
-    MemoryRepo,
-    Repo,
-)
-from dulwich.server import (
+from ..object_store import MemoryObjectStore
+from ..objects import Tree
+from ..protocol import ZERO_SHA, format_capability_line
+from ..repo import MemoryRepo, Repo
+from ..server import (
     Backend,
     DictBackend,
     FileSystemBackend,
-    MultiAckGraphWalkerImpl,
     MultiAckDetailedGraphWalkerImpl,
+    MultiAckGraphWalkerImpl,
     PackHandler,
-    _split_proto_line,
-    serve_command,
-    _find_shallow,
-    _ProtocolGraphWalker,
     ReceivePackHandler,
     SingleAckGraphWalkerImpl,
     UploadPackHandler,
+    _find_shallow,
+    _ProtocolGraphWalker,
+    _split_proto_line,
+    serve_command,
     update_server_info,
 )
-from dulwich.tests import TestCase
-from dulwich.tests.utils import (
-    make_commit,
-    make_tag,
-)
-from dulwich.protocol import (
-    ZERO_SHA,
-    format_capability_line,
-)
+from .utils import make_commit, make_tag
 
 ONE = b"1" * 40
 TWO = b"2" * 40
@@ -76,9 +66,9 @@ SIX = b"6" * 40
 
 
 class TestProto:
-    def __init__(self):
-        self._output = []
-        self._received = {0: [], 1: [], 2: [], 3: []}
+    def __init__(self) -> None:
+        self._output: List[bytes] = []
+        self._received: Dict[int, List[bytes]] = {0: [], 1: [], 2: [], 3: []}
 
     def set_output(self, output_lines):
         self._output = output_lines
@@ -106,7 +96,7 @@ class TestProto:
 
 
 class TestGenericPackHandler(PackHandler):
-    def __init__(self):
+    def __init__(self) -> None:
         PackHandler.__init__(self, Backend(), None)
 
     @classmethod
@@ -598,9 +588,9 @@ class ProtocolGraphWalkerTestCase(TestCase):
 
 
 class TestProtocolGraphWalker:
-    def __init__(self):
-        self.acks = []
-        self.lines = []
+    def __init__(self) -> None:
+        self.acks: List[bytes] = []
+        self.lines: List[bytes] = []
         self.wants_satisified = False
         self.stateless_rpc = None
         self.advertise_refs = False
