@@ -20,57 +20,43 @@
 
 """Tests for the Git HTTP server."""
 
-from io import BytesIO
 import gzip
-import re
 import os
+import re
+from io import BytesIO
 from typing import Type
 
-from dulwich.object_store import (
-    MemoryObjectStore,
-)
-from dulwich.objects import (
-    Blob,
-)
-from dulwich.repo import (
-    BaseRepo,
-    MemoryRepo,
-)
-from dulwich.server import (
-    DictBackend,
-)
-from dulwich.tests import (
-    TestCase,
-)
-from dulwich.web import (
-    HTTP_OK,
-    HTTP_NOT_FOUND,
-    HTTP_FORBIDDEN,
+from dulwich.tests import TestCase
+
+from ..object_store import MemoryObjectStore
+from ..objects import Blob
+from ..repo import BaseRepo, MemoryRepo
+from ..server import DictBackend
+from ..web import (
     HTTP_ERROR,
+    HTTP_FORBIDDEN,
+    HTTP_NOT_FOUND,
+    HTTP_OK,
     GunzipFilter,
-    send_file,
-    get_text_file,
+    HTTPGitApplication,
+    HTTPGitRequest,
+    _LengthLimitedFile,
+    get_idx_file,
+    get_info_packs,
+    get_info_refs,
     get_loose_object,
     get_pack_file,
-    get_idx_file,
-    get_info_refs,
-    get_info_packs,
+    get_text_file,
     handle_service_request,
-    _LengthLimitedFile,
-    HTTPGitRequest,
-    HTTPGitApplication,
-)
-
-from dulwich.tests.utils import (
-    make_object,
-    make_tag,
+    send_file,
 )
+from .utils import make_object, make_tag
 
 
 class MinimalistWSGIInputStream:
     """WSGI input stream with no 'seek()' and 'tell()' methods."""
 
-    def __init__(self, data):
+    def __init__(self, data) -> None:
         self.data = data
         self.pos = 0
 
@@ -96,7 +82,7 @@ class MinimalistWSGIInputStream2(MinimalistWSGIInputStream):
 class TestHTTPGitRequest(HTTPGitRequest):
     """HTTPGitRequest with overridden methods to help test caching."""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         HTTPGitRequest.__init__(self, *args, **kwargs)
         self.cached = None
 
@@ -169,7 +155,7 @@ class DumbHandlersTestCase(WebTestCase):
 
     def test_send_file_error(self):
         class TestFile:
-            def __init__(self, exc_class):
+            def __init__(self, exc_class) -> None:
                 self.closed = False
                 self._exc_class = exc_class
 
@@ -297,11 +283,11 @@ class DumbHandlersTestCase(WebTestCase):
 
     def test_get_info_packs(self):
         class TestPackData:
-            def __init__(self, sha):
+            def __init__(self, sha) -> None:
                 self.filename = "pack-%s.pack" % sha
 
         class TestPack:
-            def __init__(self, sha):
+            def __init__(self, sha) -> None:
                 self.data = TestPackData(sha)
 
         packs = [TestPack(str(i) * 40) for i in range(1, 4)]
@@ -335,7 +321,7 @@ class SmartHandlersTestCase(WebTestCase):
             proto,
             stateless_rpc=None,
             advertise_refs=False,
-        ):
+        ) -> None:
             self.args = args
             self.proto = proto
             self.stateless_rpc = stateless_rpc
@@ -563,10 +549,9 @@ class GunzipTestCase(HTTPGitApplicationTestCase):
         self._test_call(self.example_text, *self._get_zstream(self.example_text))
 
     def test_call_no_seek(self):
-        """
-        This ensures that the gunzipping code doesn't require any methods on
+        """This ensures that the gunzipping code doesn't require any methods on
         'wsgi.input' except for '.read()'.  (In particular, it shouldn't
-        require '.seek()'. See https://github.com/jelmer/dulwich/issues/140.)
+        require '.seek()'. See https://github.com/jelmer/dulwich/issues/140.).
         """
         zstream, zlength = self._get_zstream(self.example_text)
         self._test_call(
@@ -576,8 +561,7 @@ class GunzipTestCase(HTTPGitApplicationTestCase):
         )
 
     def test_call_no_working_seek(self):
-        """
-        Similar to 'test_call_no_seek', but this time the methods are available
+        """Similar to 'test_call_no_seek', but this time the methods are available
         (but defunct).  See https://github.com/jonashaag/klaus/issues/154.
         """
         zstream, zlength = self._get_zstream(self.example_text)
