@@ -19,7 +19,7 @@ _, args = getopt(sys.argv, "", [])
 
 
 if len(args) < 2:
-    print("usage: {} host:path path".format(args[0]))
+    print(f"usage: {args[0]} host:path path")
     sys.exit(1)
 
 elif len(args) < 3:
